@@ -5,7 +5,7 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/amnt_f32.rs $
-// $Revision:  $
+// $Revision: 2022-04-17T15:02:37+02:00 $
 
 /// Type used for the numerical part of a Quantity.
 ///
@@ -19,6 +19,12 @@
 /// `AmountT` depending on the configuration.
 pub type AmountT = f32;
 
+/// AmountT constant equal 0
+pub const AMNT_ZERO: AmountT = 0.;
+
+/// AmountT constant equal 1
+pub const AMNT_ONE: AmountT = 1.;
+
 #[allow(non_snake_case)]
 #[macro_export]
 /// Converts a numeric literal to an `AmountT`.
