@@ -5,25 +5,31 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/lib.rs $
-// $Revision: 2022-03-28T16:08:25+02:00 $
+// $Revision: 2022-05-04T17:19:31+02:00 $
 
 #![doc = include_str ! ("../README.md")]
 #![cfg_attr(not(feature = "std"), no_std)]
 #![allow(dead_code)]
 
-use core::cmp::Ordering;
-use core::fmt;
-use core::ops::{Add, Div, Mul, Sub};
-pub use si_prefixes::SIPrefix;
+extern crate core;
+
+use core::{
+    cmp::Ordering,
+    fmt,
+    ops::{Add, Div, Mul, Sub},
+};
 
 #[cfg(feature = "fpdec")]
-pub use amnt_dec::{AmountT, Dec, Decimal};
+pub use amnt_dec::{AmountT, Dec, Decimal, AMNT_ONE, AMNT_ZERO};
 #[cfg(all(not(feature = "fpdec"), target_pointer_width = "32"))]
-pub use amnt_f32::AmountT;
+pub use amnt_f32::{AmountT, AMNT_ONE, AMNT_ZERO};
 #[cfg(all(not(feature = "fpdec"), target_pointer_width = "64"))]
-pub use amnt_f64::AmountT;
+pub use amnt_f64::{AmountT, AMNT_ONE, AMNT_ZERO};
+pub use rate::Rate;
+pub use si_prefixes::SIPrefix;
 
 pub mod prelude;
+mod rate;
 mod si_prefixes;
 
 #[cfg(feature = "fpdec")]
@@ -68,9 +74,6 @@ pub trait Unit: Copy + Eq + PartialEq + Sized + Mul<AmountT> {
     /// Associated type of quantity
     type QuantityType: Quantity<UnitType = Self>;
 
-    /// Optional unit used as reference for scaling the units.
-    const REF_UNIT: Option<Self>;
-
     /// Returns an iterator over the variants of `Self`.
     fn iter<'a>() -> core::slice::Iter<'a, Self>;
 
@@ -85,17 +88,6 @@ pub trait Unit: Copy + Eq + PartialEq + Sized + Mul<AmountT> {
         None
     }
 
-    /// Returns `Some(unit)` where `unit.scale()` == `Some(amnt)`, or `None` if
-    /// there is no such unit.
-    fn from_scale(amnt: AmountT) -> Option<Self> {
-        for unit in Self::iter() {
-            if unit.scale() == Some(amnt) {
-                return Some(*unit);
-            }
-        }
-        None
-    }
-
     /// Returns the name of `self`.
     fn name(&self) -> &'static str;
 
@@ -105,30 +97,46 @@ pub trait Unit: Copy + Eq + PartialEq + Sized + Mul<AmountT> {
     /// Returns the SI prefix of `self`, or None is `self` is not a SI unit.
     fn si_prefix(&self) -> Option<SIPrefix>;
 
-    /// Returns `true` if `self` is the reference unit of its unit type.
-    #[inline]
-    fn is_ref_unit(&self) -> bool {
-        Self::REF_UNIT == Some(*self)
+    // Returns `1 * self`
+    fn as_qty(&self) -> Self::QuantityType {
+        Self::QuantityType::new(AMNT_ONE, *self)
+    }
+}
+
+/// Type of units being linear scaled in terms of a reference unit.
+pub trait LinearScaledUnit: Unit {
+    /// Unit used as reference for scaling the units.
+    const REF_UNIT: Self;
+
+    /// Returns `Some(unit)` where `unit.scale()` == `Some(amnt)`, or `None` if
+    /// there is no such unit.
+    fn from_scale(amnt: AmountT) -> Option<Self> {
+        for unit in Self::iter() {
+            if unit.scale() == amnt {
+                return Some(*unit);
+            }
+        }
+        None
     }
 
-    /// Returns `Some(factor)` so that `factor` * `Self::REFUNIT` == 1 * `self`,
-    /// or `None` if `Self::REF_UNIT` is `None`.
-    fn scale(&self) -> Option<AmountT>;
+    /// Returns `true` if `self` is the reference unit of its unit type.
+    #[inline(always)]
+    fn is_ref_unit(&self) -> bool {
+        *self == Self::REF_UNIT
+    }
 
-    /// Returns `Some(factor)` so that `factor` * `other` == 1 * `self`, or
-    /// `None` if `Self::REF_UNIT` is `None`.
-    fn ratio(&self, other: &Self) -> Option<AmountT> {
-        match Self::REF_UNIT {
-            Some(_) => Some(self.scale().unwrap() / other.scale().unwrap()),
-            None => None,
-        }
+    /// Returns `factor` so that `factor` * `Self::REFUNIT` == 1 * `self`.
+    fn scale(&self) -> AmountT;
+
+    /// Returns `factor` so that `factor` * `other` == 1 * `self`.
+    #[inline(always)]
+    fn ratio(&self, other: &Self) -> AmountT {
+        self.scale() / other.scale()
     }
 }
 
 /// The abstract type of quantities.
-pub trait Quantity:
-    Copy + Sized + Add<Self> + Sub<Self> + Div<Self> + Mul<AmountT>
-{
+pub trait Quantity: Copy + Sized + Mul<AmountT> {
     /// Associated type of unit
     type UnitType: Unit<QuantityType = Self>;
 
@@ -148,17 +156,6 @@ pub trait Quantity:
         None
     }
 
-    /// Returns `Some(unit)` where `unit.scale()` == `Some(amnt)`, or `None` if
-    /// there is no such unit.
-    fn unit_from_scale(amnt: AmountT) -> Option<Self::UnitType> {
-        for unit in Self::iter_units() {
-            if unit.scale() == Some(amnt) {
-                return Some(*unit);
-            }
-        }
-        None
-    }
-
     /// Returns a new instance of the type implementing `Quantity`.
     fn new(amount: AmountT, unit: Self::UnitType) -> Self;
 
@@ -168,21 +165,50 @@ pub trait Quantity:
     /// Returns the unit of `self`.
     fn unit(&self) -> Self::UnitType;
 
-    /// Returns `Some(factor)` so that `factor` * `unit` == `self`, or `None` if
-    /// such a factor can't be determined.
-    fn equiv_amount(&self, unit: Self::UnitType) -> Option<AmountT> {
-        if self.unit() == unit {
-            Some(self.amount())
+    #[inline(always)]
+    fn eq(&self, other: &Self) -> bool {
+        self.unit() == other.unit() && self.amount() == other.amount()
+    }
+
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        if self.unit() == other.unit() {
+            PartialOrd::partial_cmp(&self.amount(), &other.amount())
         } else {
-            // TODO: add converters
-            Some(self.unit().ratio(&unit)? * self.amount())
+            None
         }
     }
 
-    /// Returns `Some(qty)` where `qty` == `self` and `qty.unit()` is `to_unit`,
-    /// or `None` if the conversion can't be done.
-    fn convert(&self, to_unit: Self::UnitType) -> Option<Self> {
-        Some(Self::new(self.equiv_amount(to_unit)?, to_unit))
+    fn add(self, rhs: Self) -> Self {
+        if self.unit() == rhs.unit() {
+            return Self::new(self.amount() + rhs.amount(), self.unit());
+        }
+        panic!(
+            "Can't add '{}' and '{}'.",
+            self.unit().symbol(),
+            rhs.unit().symbol()
+        );
+    }
+
+    fn sub(self, rhs: Self) -> Self {
+        if self.unit() == rhs.unit() {
+            return Self::new(self.amount() - rhs.amount(), self.unit());
+        }
+        panic!(
+            "Can't subtract '{}' and '{}'.",
+            self.unit().symbol(),
+            rhs.unit().symbol(),
+        );
+    }
+
+    fn div(self, rhs: Self) -> AmountT {
+        if self.unit() == rhs.unit() {
+            return self.amount() / rhs.amount();
+        }
+        panic!(
+            "Can't divide '{}' and '{}'.",
+            self.unit().symbol(),
+            rhs.unit().symbol()
+        );
     }
 
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -191,57 +217,72 @@ pub trait Quantity:
             _ => write!(f, "{} {}", self.amount(), self.unit().symbol()),
         }
     }
+}
 
-    fn eq(&self, other: &Self) -> bool {
-        if self.unit() == other.unit() {
-            self.amount() == other.amount()
-        } else {
-            match other.equiv_amount(self.unit()) {
-                None => false,
-                Some(equiv_amount) => self.amount() == equiv_amount,
+/// Trait for quantities having a reference unit
+pub trait HasRefUnit: Quantity + Add<Self> + Sub<Self> + Div<Self>
+where
+    <Self as Quantity>::UnitType: LinearScaledUnit,
+{
+    /// Unit used as reference for scaling the units of `Self::UnitType`.
+    const REF_UNIT: <Self as Quantity>::UnitType;
+
+    /// Returns `Some(unit)` where `unit.scale()` == `amnt`, or `None` if
+    /// there is no such unit.
+    fn unit_from_scale(amnt: AmountT) -> Option<Self::UnitType> {
+        for unit in Self::iter_units() {
+            if unit.scale() == amnt {
+                return Some(*unit);
             }
         }
+        None
+    }
+
+    /// Returns `factor` so that `factor` * `unit` == `self`.
+    #[inline(always)]
+    fn equiv_amount(&self, unit: Self::UnitType) -> AmountT {
+        if self.unit() == unit {
+            self.amount()
+        } else {
+            self.unit().ratio(&unit) * self.amount()
+        }
+    }
+
+    /// Returns `qty` where `qty` == `self` and `qty.unit()` is `to_unit`.
+    fn convert(&self, to_unit: Self::UnitType) -> Self {
+        Self::new(self.equiv_amount(to_unit), to_unit)
+    }
+
+    #[inline(always)]
+    fn eq(&self, other: &Self) -> bool {
+        self.amount() == other.equiv_amount(self.unit())
     }
 
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         if self.unit() == other.unit() {
             PartialOrd::partial_cmp(&self.amount(), &other.amount())
         } else {
-            match self.equiv_amount(other.unit()) {
-                None => None,
-                Some(equiv_amount) => {
-                    PartialOrd::partial_cmp(&equiv_amount, &other.amount())
-                }
-            }
+            PartialOrd::partial_cmp(
+                &self.amount(),
+                &other.equiv_amount(self.unit()),
+            )
         }
     }
 
+    #[inline]
     fn add(self, rhs: Self) -> Self {
-        match rhs.equiv_amount(self.unit()) {
-            Some(equiv) => Self::new(self.amount() + equiv, self.unit()),
-            None => panic!("Incompatible units!"),
-        }
+        Self::new(self.amount() + rhs.equiv_amount(self.unit()), self.unit())
     }
 
+    #[inline]
     fn sub(self, rhs: Self) -> Self {
-        match rhs.equiv_amount(self.unit()) {
-            Some(equiv) => Self::new(self.amount() - equiv, self.unit()),
-            None => panic!("Incompatible units!"),
-        }
+        Self::new(self.amount() - rhs.equiv_amount(self.unit()), self.unit())
     }
 
+    #[inline]
     fn div(self, rhs: Self) -> AmountT {
-        match rhs.equiv_amount(self.unit()) {
-            Some(equiv) => self.amount() / equiv,
-            None => panic!("Incompatible units!"),
-        }
+        self.amount() / rhs.equiv_amount(self.unit())
     }
-}
-
-/// Trait for quantities having a reference unit
-pub trait HasRefUnit: Quantity {
-    /// Unit used as reference for scaling the units of `Self::UnitType`.
-    const REF_UNIT: <Self as Quantity>::UnitType;
 
     #[doc(hidden)]
     /// Returns a new instance of the type implementing `HasRefUnit`, equivalent
@@ -256,15 +297,11 @@ pub trait HasRefUnit: Quantity {
         // `it` returns atleast the reference unit, so its safe to unwrap here
         let first = it.next().unwrap();
         let last = it
-            .filter(|u| {
-                u.scale().is_some()
-                    && u.scale().unwrap() > first.scale().unwrap()
-                    && u.scale().unwrap() <= amount
-            })
+            .filter(|u| u.scale() > first.scale() && u.scale() <= amount)
             .last();
         match last {
-            Some(unit) => Self::new(amount / unit.scale().unwrap(), *unit),
-            None => Self::new(amount / first.scale().unwrap(), *first),
+            Some(unit) => Self::new(amount / unit.scale(), *unit),
+            None => Self::new(amount / first.scale(), *first),
         }
     }
 }
@@ -284,7 +321,6 @@ pub const ONE: One = One::One;
 
 impl Unit for One {
     type QuantityType = AmountT;
-    const REF_UNIT: Option<Self> = Some(ONE);
     fn iter<'a>() -> core::slice::Iter<'a, Self> {
         Self::VARIANTS.iter()
     }
@@ -297,8 +333,12 @@ impl Unit for One {
     fn si_prefix(&self) -> Option<SIPrefix> {
         None
     }
-    fn scale(&self) -> Option<AmountT> {
-        Some(Amnt!(1.))
+}
+
+impl LinearScaledUnit for One {
+    const REF_UNIT: Self = ONE;
+    fn scale(&self) -> AmountT {
+        AMNT_ONE
     }
 }
 
