@@ -5,17 +5,22 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/prelude.rs $
-// $Revision: 2022-02-10T18:40:51+01:00 $
+// $Revision: 2022-04-17T17:08:57+02:00 $
 
 //! This module reexports all macros and types needed to define a quantity.
 
-pub use crate::{Amnt, AmountT, HasRefUnit, Quantity, SIPrefix, Unit, ONE};
-#[cfg(feature = "fpdec")]
-pub use crate::{Dec, Decimal};
 #[doc(hidden)]
 pub use core::cmp::Ordering;
 #[doc(hidden)]
 pub use core::fmt;
 #[doc(hidden)]
 pub use core::ops::{Add, Div, Mul, Sub};
+
 pub use qty_macros::quantity;
+
+pub use crate::{
+    Amnt, AmountT, HasRefUnit, LinearScaledUnit, Quantity, Rate, SIPrefix,
+    Unit, ONE,
+};
+#[cfg(feature = "fpdec")]
+pub use crate::{Dec, Decimal};
