@@ -5,12 +5,11 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: tests/test_qty.rs $
-// $Revision: 2022-02-17T16:39:59+01:00 $
+// $Revision: 2022-05-04T21:33:17+02:00 $
 
 #[cfg(test)]
 mod quantity_with_ref_unit_tests {
-    use quantities::assert_almost_eq;
-    use quantities::prelude::*;
+    use quantities::{assert_almost_eq, prelude::*, AMNT_ONE};
 
     /// Foo, a completely useless quantity
     #[quantity]
@@ -26,13 +25,13 @@ mod quantity_with_ref_unit_tests {
         assert_eq!(a.name(), "A");
         assert_eq!(a.symbol(), "a");
         assert_eq!(a.si_prefix(), Some(SIPrefix::MEGA));
-        assert_eq!(a.scale().unwrap(), Amnt!(1.0));
+        assert_eq!(a.scale(), Amnt!(1.0));
         assert_eq!(b.name(), "B");
         assert_eq!(b.symbol(), "b");
         assert_eq!(b.si_prefix(), None);
-        assert_eq!(b.scale().unwrap(), Amnt!(0.4));
-        assert_eq!(b.ratio(&a).unwrap(), Amnt!(0.4));
-        assert_eq!(a.ratio(&b).unwrap(), Amnt!(2.5));
+        assert_eq!(b.scale(), Amnt!(0.4));
+        assert_eq!(b.ratio(&a), Amnt!(0.4));
+        assert_eq!(a.ratio(&b), Amnt!(2.5));
     }
 
     #[test]
@@ -54,7 +53,7 @@ mod quantity_with_ref_unit_tests {
 
     #[test]
     fn test_unit_from_scale() {
-        assert_eq!(FooUnit::from_scale(Amnt!(1)), Some(A));
+        assert_eq!(FooUnit::from_scale(AMNT_ONE), Some(A));
         assert_eq!(FooUnit::from_scale(Amnt!(0.4)), Some(B));
         assert_eq!(FooUnit::from_scale(Amnt!(0.01)), Some(C));
         assert_eq!(FooUnit::from_scale(Amnt!(10)), None);
@@ -99,7 +98,7 @@ mod quantity_with_ref_unit_tests {
 
     #[test]
     fn test_qty_unit_from_scale() {
-        assert_eq!(Foo::unit_from_scale(Amnt!(1)), Some(A));
+        assert_eq!(Foo::unit_from_scale(AMNT_ONE), Some(A));
         assert_eq!(Foo::unit_from_scale(Amnt!(0.4)), Some(B));
         assert_eq!(Foo::unit_from_scale(Amnt!(0.01)), Some(C));
         assert_eq!(Foo::unit_from_scale(Amnt!(10)), None);
@@ -126,10 +125,10 @@ mod quantity_with_ref_unit_tests {
     #[test]
     fn test_convert() {
         let qty = Foo::new(Amnt!(17.4), FooUnit::B);
-        let equiv = qty.convert(FooUnit::A).unwrap();
+        let equiv = qty.convert(FooUnit::A);
         assert_almost_eq!(equiv.amount(), Amnt!(6.96));
         assert_eq!(equiv.unit(), FooUnit::A);
-        let qty = equiv.convert(FooUnit::B).unwrap();
+        let qty = equiv.convert(FooUnit::B);
         assert_almost_eq!(qty.amount(), Amnt!(17.4));
         assert_eq!(qty.unit(), FooUnit::B);
     }
@@ -153,7 +152,7 @@ mod quantity_with_ref_unit_tests {
     fn test_cmp_diff_unit() {
         let qty1 = Amnt!(17.4) * FooUnit::A;
         let qty2 = Amnt!(0.37) * FooUnit::B;
-        let qty3 = qty1.convert(FooUnit::C).unwrap();
+        let qty3 = qty1.convert(FooUnit::C);
         assert!(qty1 == qty3);
         assert!(qty3 == qty1);
         assert!(qty1 != qty2);
@@ -279,8 +278,7 @@ mod quantity_with_ref_unit_tests {
 
 #[cfg(test)]
 mod quantity_without_ref_unit_tests {
-    use quantities::assert_almost_eq;
-    use quantities::prelude::*;
+    use quantities::{assert_almost_eq, prelude::*};
 
     /// Foo, a completely useless quantity
     #[quantity]
@@ -291,14 +289,10 @@ mod quantity_without_ref_unit_tests {
 
     #[test]
     fn test_unit() {
-        let a = A;
         let b = B;
         assert_eq!(b.name(), "B");
         assert_eq!(b.symbol(), "b");
         assert!(b.si_prefix().is_none());
-        assert!(b.scale().is_none());
-        assert!(b.ratio(&a).is_none());
-        assert!(a.ratio(&b).is_none());
     }
 
     #[test]
@@ -319,14 +313,6 @@ mod quantity_without_ref_unit_tests {
         assert_eq!(iter_units.next(), None);
     }
 
-    #[test]
-    fn test_convert() {
-        let qty = Foo::new(Amnt!(17.4), B);
-        assert!(qty.convert(A).is_none());
-        let qty = Foo::new(Amnt!(6.25), A);
-        assert!(qty.convert(B).is_none());
-    }
-
     #[test]
     fn test_cmp_same_unit() {
         let qty1 = Amnt!(17.4) * FooUnit::A;
@@ -359,9 +345,9 @@ mod quantity_without_ref_unit_tests {
 
     #[test]
     fn test_add_same_unit() {
-        let amnt1 = Amnt!(0.1);
-        let unit1 = FooUnit::A;
-        let amnt2 = Amnt!(0.2);
+        let amnt1 = Amnt!(5000.17);
+        let unit1 = FooUnit::C;
+        let amnt2 = Amnt!(-2);
         let qty1 = amnt1 * unit1;
         let qty2 = amnt2 * unit1;
         let res = qty1 + qty2;
@@ -375,8 +361,12 @@ mod quantity_without_ref_unit_tests {
     #[test]
     #[should_panic]
     fn test_add_diff_unit() {
-        let qty1 = Amnt!(17.4) * A;
-        let qty2 = Amnt!(0.37) * B;
+        let amnt1 = Amnt!(17.4);
+        let unit1 = FooUnit::A;
+        let amnt2 = Amnt!(0.37);
+        let unit2 = FooUnit::B;
+        let qty1 = amnt1 * unit1;
+        let qty2 = amnt2 * unit2;
         let _res = qty1 + qty2;
     }
 
@@ -398,8 +388,12 @@ mod quantity_without_ref_unit_tests {
     #[test]
     #[should_panic]
     fn test_sub_diff_unit() {
-        let qty1 = Amnt!(17.4) * A;
-        let qty2 = Amnt!(0.37) * B;
+        let amnt1 = Amnt!(17.4);
+        let unit1 = FooUnit::A;
+        let amnt2 = Amnt!(0.3);
+        let unit2 = FooUnit::B;
+        let qty1 = amnt1 * unit1;
+        let qty2 = amnt2 * unit2;
         let _res = qty1 - qty2;
     }
 
@@ -411,22 +405,25 @@ mod quantity_without_ref_unit_tests {
         let qty1 = amnt1 * unit1;
         let qty2 = amnt2 * unit1;
         let res = qty1 / qty2;
-        assert_almost_eq!(res.amount(), amnt1 / amnt2);
-        assert_eq!(res.unit(), ONE);
+        assert_almost_eq!(res, amnt1 / amnt2);
     }
 
     #[test]
     #[should_panic]
     fn test_div_diff_unit() {
-        let qty1 = Amnt!(17.4) * A;
-        let qty2 = Amnt!(0.3) * B;
+        let amnt1 = Amnt!(17.4);
+        let unit1 = FooUnit::A;
+        let amnt2 = Amnt!(0.3);
+        let unit2 = FooUnit::B;
+        let qty1 = amnt1 * unit1;
+        let qty2 = amnt2 * unit2;
         let _res = qty1 / qty2;
     }
 }
 
 #[cfg(test)]
 mod quantity_single_unit_tests {
-    use quantities::prelude::*;
+    use quantities::{assert_almost_eq, prelude::*};
 
     #[quantity]
     #[unit(Pop, "p")]
@@ -458,12 +455,51 @@ mod quantity_single_unit_tests {
         assert_eq!(qty.amount(), amnt);
         assert_eq!(qty.unit(), POP);
     }
+
+    #[test]
+    fn test_add() {
+        let amnt1 = Amnt!(517.04);
+        let amnt2 = Amnt!(14.3);
+        let qty1 = amnt1 * POP;
+        let qty2 = amnt2 * POP;
+        let res = qty1 + qty2;
+        assert_almost_eq!(res.amount(), amnt1 + amnt2);
+        assert_eq!(res.unit(), POP);
+        let res = qty2 + qty1;
+        assert_almost_eq!(res.amount(), amnt1 + amnt2);
+        assert_eq!(res.unit(), POP);
+    }
+
+    #[test]
+    fn test_sub() {
+        let amnt1 = Amnt!(14.3);
+        let amnt2 = Amnt!(517.04);
+        let qty1 = amnt1 * POP;
+        let qty2 = amnt2 * POP;
+        let res = qty1 - qty2;
+        assert_almost_eq!(res.amount(), amnt1 - amnt2);
+        assert_eq!(res.unit(), POP);
+        let res = qty2 - qty1;
+        assert_almost_eq!(res.amount(), amnt2 - amnt1);
+        assert_eq!(res.unit(), POP);
+    }
+
+    #[test]
+    fn test_div() {
+        let amnt1 = Amnt!(510.4);
+        let amnt2 = Amnt!(1.407);
+        let qty1 = amnt1 * POP;
+        let qty2 = amnt2 * POP;
+        let res = qty1 / qty2;
+        assert_almost_eq!(res, amnt1 / amnt2);
+        let res = qty2 / qty1;
+        assert_almost_eq!(res, amnt2 / amnt1);
+    }
 }
 
 #[cfg(test)]
 mod derived_quantity_tests {
-    use quantities::assert_almost_eq;
-    use quantities::prelude::*;
+    use quantities::{assert_almost_eq, prelude::*};
 
     #[quantity]
     #[ref_unit(Flop, "f")]
@@ -513,10 +549,10 @@ mod derived_quantity_tests {
         assert_almost_eq!(z.amount(), r.amount());
         assert_eq!(z.unit(), r.unit());
         // reverse divs
-        let z = (r / x).convert(y.unit()).unwrap();
+        let z = (r / x).convert(y.unit());
         assert_almost_eq!(z.amount(), y.amount());
         assert_eq!(z.unit(), y.unit());
-        let z = (r / y).convert(x.unit()).unwrap();
+        let z = (r / y).convert(x.unit());
         assert_almost_eq!(z.amount(), x.amount());
         assert_eq!(z.unit(), x.unit());
     }
@@ -545,7 +581,7 @@ mod derived_quantity_tests {
         assert_almost_eq!(z.amount(), r.amount());
         assert_eq!(z.unit(), r.unit());
         // reverse mul
-        let z = (r * y).convert(x.unit()).unwrap();
+        let z = (r * y).convert(x.unit());
         assert_almost_eq!(z.amount(), x.amount());
         assert_eq!(z.unit(), x.unit());
     }
